@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-noter" "1.6.1"
+(define-package "org-noter" "20250730.30"
   "A synchronized, Org-mode, document annotator."
   '((emacs  "24.4")
     (cl-lib "0.6")
     (org    "9.4"))
   :url "https://github.com/org-noter/org-noter"
-  :commit "284b425f7275ca04bab0f691dfe284a4e059288c"
-  :revdesc "284b425f7275"
+  :commit "aafa08a49c4c3311d9b17864629aceeff02d33da"
+  :revdesc "aafa08a49c4c"
   :keywords '("lisp" "pdf" "interleave" "annotate" "external" "sync" "notes" "documents" "org-mode")
   :authors '(("Gonçalo Santos" . "in@bsentia")
              ("Maintainer Dmitry M" . "dmitrym@gmail.com"))
